@@ -23,6 +23,7 @@ def getImagesAndTotDiff(head, rayon, cap1, cap2, videoPath, l, frameGapComparisi
   ymin = headY - rayon
   xmax = xmin + 2 * rayon
   ymax = ymin + 2 * rayon
+  
   if xmin < 0:
     xmin = 0
   if ymin < 0:
@@ -41,14 +42,17 @@ def getImagesAndTotDiff(head, rayon, cap1, cap2, videoPath, l, frameGapComparisi
   if ( (xmin > lenX - 1) or (xmax < 0) ):
     xmin = 0
     xmax = 0 + lenX - 1
-
+  
   if ( (ymin > lenY - 1) or (ymax < 0) ):
     ymin = 0
     ymax = 0 + lenY - 1
-
+  
   if hyperparameters["adjustDetectMovWithRawVideo"]:
-    img = getImage(videoPath, l, wellNumber, wellPositions, hyperparameters)
-    imgFuture = getImage(videoPath, l+frameGapComparision, wellNumber, wellPositions, hyperparameters)  
+    img       = cap1[l - firstFrame]
+    if l + frameGapComparision - firstFrame < len(cap1):
+      imgFuture = cap1[int(l + frameGapComparision - firstFrame)]
+    else:
+      imgFuture = cap1[len(cap1) - 1]
   else:
     img = getImageSequential(cap1, videoPath, l, wellNumber, wellPositions, hyperparameters)
     imgFuture = getImageSequential(cap2, videoPath, l+frameGapComparision, wellNumber, wellPositions, hyperparameters)
@@ -85,7 +89,7 @@ def getImagesAndTotDiff(head, rayon, cap1, cap2, videoPath, l, frameGapComparisi
   
   res = cv2.absdiff(img22, imgFuture22)
   
-  if len(headPosition) and len(tailTip):
+  if type(headPosition) != int and type(tailTip) != int and len(headPosition) and len(tailTip):
     # Setting to black everything outside of a rectangle centered on the tail
     stencil = np.zeros(res.shape).astype(res.dtype)
     dist = (math.sqrt((headPosition[0] - tailTip[0])**2 + (headPosition[1] - tailTip[1])**2))*1.2
@@ -128,12 +132,12 @@ def detectMovementWithRawVideo(hyperparameters, videoPath, background, wellNumbe
     cv2.namedWindow("debugDetectMovWithRawVideo")
     cv2.moveWindow("debugDetectMovWithRawVideo", 0, 0)
   
-  if hyperparameters["wellsAreRectangles"]:
-    lenX = int(wellPositions[wellNumber]["lengthX"])
-    lenY = int(wellPositions[wellNumber]["lengthY"])
-  else:
-    lenX = hyperparameters["wellOutputVideoDiameter"]
-    lenY = hyperparameters["wellOutputVideoDiameter"]
+  # if hyperparameters["wellsAreRectangles"]:
+  lenX = int(wellPositions[wellNumber]["lengthX"])
+  lenY = int(wellPositions[wellNumber]["lengthY"])
+  # else:
+    # lenX = hyperparameters["wellOutputVideoDiameter"]
+    # lenY = hyperparameters["wellOutputVideoDiameter"]
   
   firstFrame = hyperparameters["firstFrame"]
   lastFrame  = hyperparameters["lastFrame"]
@@ -144,11 +148,19 @@ def detectMovementWithRawVideo(hyperparameters, videoPath, background, wellNumbe
   
   mouvement = [0] * (max_l-debut_l+1)
   
-  cap1 = cv2.VideoCapture(videoPath)
-  cap1.set(1, debut_l)
-  
-  cap2 = cv2.VideoCapture(videoPath)
-  cap2.set(1, debut_l + hyperparameters["frameGapComparision"])
+  if hyperparameters["adjustDetectMovWithRawVideo"]:
+    cap1 = []
+    cap2 = 0
+    cap = cv2.VideoCapture(videoPath)
+    cap.set(1, debut_l)
+    for k in range(debut_l, max_l):
+      imgTemp = getImageSequential(cap, videoPath, k, wellNumber, wellPositions, hyperparameters)
+      cap1.append(imgTemp)
+  else:
+    cap1 = cv2.VideoCapture(videoPath)
+    cap1.set(1, debut_l)
+    cap2 = cv2.VideoCapture(videoPath)
+    cap2.set(1, debut_l + hyperparameters["frameGapComparision"])
   
   while ((l < max_l) and (l-firstFrame < len(head))) or hyperparameters["adjustDetectMovWithRawVideo"]:
     if l >= debut_l:
@@ -178,7 +190,12 @@ def detectMovementWithRawVideo(hyperparameters, videoPath, background, wellNumbe
         if len(organizationTabCur) == 0:
           organizationTabCur = organizationTab
       
+        if l + hyperparameters["frameGapComparision"] > hyperparameters["lastFrame"]:
+          l = int(hyperparameters["lastFrame"] - hyperparameters["frameGapComparision"] - 3)
         [l, hyperparameters, organizationTabCur] = adjustHyperparameters(l, hyperparameters, hyperparametersListNames, frameToShow, WINDOW_NAME, organizationTabCur)
+        if l + hyperparameters["frameGapComparision"] > hyperparameters["lastFrame"]:
+          l = int(hyperparameters["lastFrame"] - hyperparameters["frameGapComparision"] - 3)
+          
       else:
         l = l + 1
       
